steamstore API documentation
Description: steamstore.py - A Python wrapper for the Public Steam StoreFront API

# Package `steamstore`

steamstore.py - A Python wrapper for the Public Steam StoreFront API

Expand source code

    """steamstore.py - A Python wrapper for the Public Steam StoreFront API"""

    __version__ = '0.0.6'
    __author__ = 'Sauce <saucesteals@gmail.com>'
    __all__ = []

    from .client import Client
    from .app import *

## Sub-modules

`steamstore.app`
`steamstore.client`
`steamstore.defaults`
`steamstore.featured`